<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/revisions?lang_cible=vi
// ** ne pas modifier le fichier **

return [

	// D
	'diff_para_ajoute' => 'Đoạn văn thêm vào',
	'diff_para_deplace' => 'Đoạn văn dời đi',
	'diff_para_supprime' => 'Đoạn văn bị xóa',
	'diff_texte_ajoute' => 'Văn bản thêm vào',
	'diff_texte_deplace' => 'Văn bản dời đi',
	'diff_texte_supprime' => 'Văn bản bị xóa',

	// I
	'info_historique' => 'Sửa đổi:',
	'info_historique_lien' => 'Hiển thị danh sách các ấn bản',
	'info_historique_titre' => 'Theo dõi sửa đổi',

	// V
	'version_initiale' => 'Ấn bản đầu tiên',
];
